attempt to fix build/version.txt in bootcd image
[bootcd.git] / prep.sh
diff --git a/prep.sh b/prep.sh
index e36d4c8..ba985b9 100755 (executable)
--- a/prep.sh
+++ b/prep.sh
@@ -8,8 +8,6 @@
 # Mark Huang <mlhuang@cs.princeton.edu>
 # Copyright (C) 2004-2006 The Trustees of Princeton University
 #
-# $Id$
-#
 
 PATH=/sbin:/bin:/usr/sbin:/usr/bin
 
@@ -28,44 +26,10 @@ export PATH
 
 . build.common
 
-# pldistro expected as $1 - defaults to planetlab
-pldistro=planetlab
-[ -n "$@" ] && pldistro=$1
-
-# Packages to install : see <pldistro>-bootcd.lst
-
-# Unnecessary junk
-junk=(
-lib/obsolete
-lib/tls
-usr/share/cracklib
-usr/share/emacs
-usr/share/gnupg
-usr/share/i18n
-usr/share/locale
-usr/share/terminfo
-usr/share/zoneinfo
-usr/sbin/build-locale-archive
-usr/sbin/dbconverter-2
-usr/sbin/sasl*
-usr/sbin/tcpslice
-usr/lib/perl*
-usr/lib/locale
-usr/lib/sasl*
-usr/lib/gconv
-usr/lib/tls
-)
-
-precious=(
-usr/share/i18n/locales/en_US
-usr/share/i18n/charmaps/UTF-8.gz
-usr/share/locale/en
-usr/share/terminfo/l/linux
-usr/share/terminfo/v/vt100
-usr/share/terminfo/x/xterm
-usr/share/zoneinfo/UTC
-usr/lib/locale/en_US.utf8
-)
+pldistro=$1 ; shift
+nodefamily=$1; shift
+
+# Packages to install, junk and precious : see build/<pldistro>/bootcd.pkgs
 
 # Do not tolerate errors
 set -e
@@ -75,49 +39,74 @@ bootcd=$PWD/build/bootcd
 install -d -m 755 $bootcd
 
 # Write version number
-rpmquery --specfile bootcd.spec --queryformat '%{VERSION}\n' | head -1 >build/version.txt
+rpm -q --specfile bootcd.spec --queryformat '%{VERSION}\n' | head -1 > build/version.txt
+echo $nodefamily > build/nodefamily
 
 # Install base system
-lst=${pldistro}-bootcd.lst
-options=$(pl_getPackagesOptions2 ${pl_DISTRO_NAME} $lst)
-
-pl_setup_chroot $bootcd $options -k
-
-pushd $bootcd
-
-echo "* Removing unnecessary junk"
-
-# Save precious files
-tar --ignore-failed-read -cpf precious.tar ${precious[*]}
+echo "* Creating fedora root image"
+pl_root_makedevs $bootcd
+pkgsfile=$(pl_locateDistroFile ../build/ $pldistro bootcd.pkgs) 
+pl_root_mkfedora $bootcd $pldistro $pkgsfile
+pl_root_tune_image $bootcd
 
-# Remove unnecessary junk
-rm -rf ${junk[*]}
-
-# Restore precious files
-tar -xpf precious.tar
-rm -f precious.tar
-
-popd
+# Add site_admin console account to BootCD: with root priv, and empty passwd
+CRYPT_SA_PASSWORD=$(python -c "import crypt, random, string; salt = [random.choice(string.letters + string.digits + \"./\") for i in range(0,8)] ; print crypt.crypt('site_admin', '\$1\$' + \"\".join(salt) + '\$')")
+chroot ${bootcd} /usr/sbin/useradd -p "$CRYPT_SA_PASSWORD" -o -g 0 -u 0 -m site_admin
 
 # Install ipnmac (for SuperMicro machines with IPMI)
 echo "* Installing IPMI utilities"
 install -D -m 755 ipnmac/ipnmac.x86 $bootcd/usr/sbin/ipnmac
 
+# Install initscripts
+echo "* Installing initscripts"
+for file in pl_functions pl_sysinit pl_hwinit pl_netinit pl_validateconf pl_boot ; do
+    sed -i -e "s,@PLDISTRO@,$pldistro,g" -e "s,@FCDISTRO@,$fcdistro,g" initscripts/$file
+    install -D -m 755 initscripts/$file $bootcd/etc/init.d/$file
+done
+
 # Install configuration files
 echo "* Installing configuration files"
 for file in fstab mtab modprobe.conf inittab hosts sysctl.conf ; do
-    install -D -m 644 conf_files/$file $bootcd/etc/$file
-done
-
-# Install initscripts
-echo "* Installing initscripts"
-for file in pl_sysinit pl_hwinit pl_netinit pl_validateconf pl_boot ; do
-    install -D -m 755 conf_files/$file $bootcd/etc/init.d/$file
+    install -D -m 644 etc/$file $bootcd/etc/$file
 done
+# connect our initscripts scripts for upstart
+# fedora 9 comes with /sbin/init from upstart, that uses /etc/event.d instead of inittab
+# (in fact inittab is read for determining the default runlevel)
+if [ -d $bootcd/etc/event.d ] ; then
+    echo "* Tuning /etc/event.d/ for upstart"
+    pushd $bootcd/etc/event.d
+    # use our system initialisation script
+    sed -i -e 's,/etc/rc\.d/rc\.sysinit[a-z\.]*,/etc/init.d/pl_sysinit,g' rcS
+    # use our startup script in runlevel 2
+    sed -i -e 's,/etc/rc\.d/rc[ \t][ \t]*2,/etc/init.d/pl_boot,g' rc2
+    popd    
+fi
+# ditto for f14 and higher init style
+if [ -d $bootcd/etc/init ] ; then
+    echo "* Tuning /etc/init/ for upstart"
+    pushd $bootcd/etc/init
+    # use our system initialisation script
+    sed -i -e 's,/etc/rc\.d/rc\.sysinit[a-z\.]*,/bin/bash -c /etc/init.d/pl_sysinit,g' rcS.conf
+    # use our startup script in runlevel 2
+    sed -i -e 's,/etc/rc.d/rc[a-z\.]*,/etc/init.d/pl_boot,g' rc.conf
+    popd    
+fi
+# Install systemd files for f16 and above
+if [ -d $bootcd/etc/systemd/system ] ; then
+    echo "* Installing systemd files"
+    for file in pl_boot.service pl_boot.target ; do
+        install -D -m 644 systemd/$file $bootcd/etc/systemd/system
+    done
+    echo "* Enabling getty on tty2"
+    # select pl_boot target this way instead of using kargs, as kargs apply to kexec boot as well
+    ln -sf /etc/systemd/system/pl_boot.target $bootcd/etc/systemd/system/default.target
+    [ -d $bootcd/etc/systemd/system/default.target.wants ] || mkdir -p $bootcd/etc/systemd/system/default.target.wants
+    ln -sf /usr/lib/systemd/system/getty@.service $bootcd/etc/systemd/system/default.target.wants/getty@tty2.service
+fi
 
 # Install fallback node configuration file
 echo "* Installing fallback node configuration file"
-install -D -m 644 conf_files/default-net.cnf $bootcd/usr/boot/default-net.cnf
+install -D -m 644 usr-boot/default-node.txt $bootcd/usr/boot/default-node.txt
 
 # Copy /etc/passwd out
 install -D -m 644 $bootcd/etc/passwd build/passwd
@@ -141,14 +130,6 @@ ln -sf /sbin/init $bootcd/init
 
 # Pack the rest into a compressed archive
 echo "* Compressing reference image"
-(cd $bootcd && find . | cpio --quiet -c -o) | gzip -9 >$isofs/bootcd.img
-
-# Build syslinux
-echo "* Building syslinux"
-CFLAGS="-Werror -Wno-unused -finline-limit=2000" make -C syslinux
-
-# Install isolinux
-echo "* Installing isolinux"
-install -D -m 644 syslinux/isolinux.bin $isofs/isolinux.bin
+(cd $bootcd && find . | cpio --quiet -c -o) | gzip -9 > $isofs/bootcd.img
 
 exit 0